---
hologram: true
title: Guidelines
name: index
category: index
---

### Conventions

* Use soft-tabs with a two space indent.
* Keep sorted in first alphabetical order of rule declarations.
* Put spaces before `{` in declarations.
* Put spaces after `:` in declarations.
* Put line breaks between rulesets.
* Place closing braces of declaration blocks on a new line.
* When grouping selectors, keep individual selectors to a single line.

examples

```
.recipes-order {
  border-bottom: 1px solid #ebe5e1;
  line-height: 1.7;
  margin-bottom: 0;
  padding-bottom: 10px;
  text-align: right;

  a {
    color: #999;

    &:hover {
      color: #5c4545;
    }
  }
}
```

<br/>
// keep individual selectors to a single line while grouping selectors

```
.fav-count,
.view-count,
.dish-count {
  font-size: 12px;
  margin-right: 0;
}
```
<br/>
<hr/>
### Formating

* Specifying units for zero values, write `margin: 0;` instead of `margin: 0px;` .
* Use hex color for rules, e.g., `#000` instead of `#000000` .
* Use `//` for comment blocks instead of `/* */` .
* Use `-` instead of `_` or camel case for naming.

examples

// default block style

```
.inner-block {
  border: 1px solid #eeede8;
  color: #000;
  margin-top: 0;
}
```

<br/>
<hr/>
### Misc

* For the nesting in SCSS, four levels deep is the limit. (...OK, let's aim the goal to three levels !)
* Never ever let your codelines up to more than 200 lines in every single file. Once you over lines, then you need to step back and rethink your overall strategy. (e.g., does it need to be break into as several small files as makes sense? or ask yourself is there something wrong with my thought ?...)
* List `@extend` or `@include` first ( `@extend` must be the first when both them exist) before regular rules.
* Prefer import specific things when you need it in single file instead of `@import "compass";` in only one main file.
* Partials should be named with `_`, e.g., `_recipe-card.scss` .

examples

```
@import "compass/css3/transition";

.group_1 {
  @extend .group;
  @include transition(all 0.3s ease);

  background-color: #ebe5e1;
  border: 1px solid #d8f0d8;

  .group-name {
    background-color: #d8f0d8;
    border-bottom: 1px solid #d8f0d8;
    color: #3c4e3c;
  }
}

```
